@@ -10,4 +10,8 @@ def test_pdf():
     office.pdf.add_watermark()
 
 
-test_pdf()
+def test_wordcloud():
+    office.image.txt2wordcloud('yes-minister.txt')
+
+
+test_wordcloud()
